"use strict";
var _index = _interopRequireDefault(require("./index"));
function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    };
}
describe('validate', ()=>{
    test('should return true if doi is correct', ()=>{
        expect(_index.default.validate('10.1234/56789')).toBe(true);
    });
    test('empty is not a validPart', ()=>{
        expect(_index.default.validatePart()).toBe(false);
        expect(_index.default.validatePart('')).toBe(false);
    });
    test('empty is not valid', ()=>{
        expect(_index.default.validate()).toBe(false);
        expect(_index.default.validate('')).toBe(false);
    });
    test.each([
        'https://doi.org/10.1371/journal.pclm.0000068',
        'doi:10.1234/56789',
        '10.1234/56789',
        'doi.org/10.1371/journal.pclm.0000068', 
    ])('Validate works for %p', (valid)=>{
        expect(_index.default.validate(valid)).toBe(true);
    });
    // can expand on here if needed
    test.each([
        'https://doi.org/10.1371/journal.pclm.0000068',
        ':10.1234/56789a',
        'doi:10.1234/56789', 
    ])('should not validatePart when it is %p', (invalid)=>{
        expect(_index.default.validatePart(invalid)).toBe(false);
    });
});
describe('buildDoiUrl', ()=>{
    test('should build doi.org url with doi', ()=>{
        expect(_index.default.buildUrl('10.1234/56789')).toBe('https://doi.org/10.1234/56789');
    });
    test.each([
        [
            'http://dx.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'http://www.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'http://doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'www.doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'doi.org/10.1016/j.cageo.2015.09.015'
        ],
        [
            'doi.something.else/10.1016/j.cageo.2015.09.015'
        ],
        [
            'something.else/doi/10.1016/j.cageo.2015.09.015'
        ], 
    ])('should normalize url when it is %p', (doiString)=>{
        expect(_index.default.buildUrl(doiString)).toBe('https://doi.org/10.1016/j.cageo.2015.09.015');
    });
});
describe('normalize', ()=>{
    test('should remove "doi:"', ()=>{
        expect(_index.default.normalize('doi:10.1234/56789')).toBe('10.1234/56789');
    });
    test('should extract doi from doi.org url', ()=>{
        expect(_index.default.normalize('doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
    test('should extract doi from doi.org url with http protocol', ()=>{
        expect(_index.default.normalize('https://doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
    test('should handle www.', ()=>{
        expect(_index.default.normalize('http://www.doi.org/10.1234/56789')).toBe('10.1234/56789');
    });
});
describe('external DOI links', ()=>{
    test.each([
        [
            'elife',
            'https://elifesciences.org/articles/59045',
            '10.7554/eLife.59045'
        ],
        [
            'zenodo',
            'https://zenodo.org/badge/latestdoi/169800572',
            '10.5281/zenodo.169800572'
        ],
        [
            'joss',
            'https://joss.theoj.org/papers/10.21105/joss.04767',
            '10.21105/joss.04767'
        ],
        [
            'pathnames',
            'https://pangaea.de/doi/10.1594/PANGAEA.941238',
            '10.1594/PANGAEA.941238'
        ],
        [
            'subdomains',
            'https://doi.pangaea.de/10.1594/PANGAEA.941238',
            '10.1594/PANGAEA.941238'
        ], 
    ])('Test %s (%s) <%s>', (_, url, doiString)=>{
        expect(_index.default.normalize(url)).toBe(doiString);
        expect(_index.default.validate(url)).toBe(true);
        expect(_index.default.validate(url, {
            strict: true
        })).toBe(false);
    });
});

//# sourceMappingURL=index.spec.js.map