"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.DEFAULT_RESOLVERS = exports.STRICT_RESOLVERS = void 0;
var _validatePart = require("./validatePart");
const doiOrg = {
    test (url) {
        return !!url.hostname.match(/(?:dx\.)?(?:www\.)?doi\.org/);
    },
    parse (url) {
        return url.pathname.replace(/^\//, '');
    }
};
const doiSubdomain = {
    test (url) {
        return !!url.hostname.match(/(?:^|\.)doi./) || url.pathname.includes('/doi/');
    },
    parse (url) {
        return url.pathname.replace(/\/doi\//, '').replace(/^\//, '');
    }
};
const elife = {
    test (url) {
        return url.hostname.endsWith('elifesciences.org') && url.pathname.startsWith('/articles/');
    },
    parse (url) {
        return `10.7554/eLife.${url.pathname.replace('/articles/', '')}`;
    }
};
const zenodo = {
    test (url) {
        return url.hostname.endsWith('zenodo.org') && !!url.pathname.match(/^\/(?:record|badge\/latestdoi)\//);
    },
    parse (url) {
        return `10.5281/zenodo.${url.pathname.replace(/^\/(?:record|badge\/latestdoi)\//, '')}`;
    }
};
function clumpParts(url) {
    const parts = url.pathname.split('/').filter((p)=>!!p
    );
    return parts.slice(0, -1).map((a, i)=>`${a}/${parts[i + 1]}`
    );
}
const pathParts = {
    test (url) {
        return !!clumpParts(url).find(_validatePart.validatePart);
    },
    parse (url) {
        return clumpParts(url).find(_validatePart.validatePart);
    }
};
const STRICT_RESOLVERS = [
    doiOrg
];
exports.STRICT_RESOLVERS = STRICT_RESOLVERS;
const DEFAULT_RESOLVERS = [
    doiOrg,
    doiSubdomain,
    elife,
    zenodo,
    pathParts
];
exports.DEFAULT_RESOLVERS = DEFAULT_RESOLVERS;

//# sourceMappingURL=resolvers.js.map