import { validatePart } from './validatePart';
export { DEFAULT_RESOLVERS, STRICT_RESOLVERS } from './resolvers';
export declare type Options = {
    strict?: boolean;
};
/**
 * Validate that the input string is valid.
 *
 * Uses DOI pattern described here: https://www.crossref.org/blog/dois-and-matching-regular-expressions/
 *
 * @param possibleDOI
 * @returns true if DOI is valid
 */
declare function validate(possibleDOI?: string, opts?: Options): boolean;
/**
 * Normalize an input string to the component of the DOI
 *
 * @param possibleDOI
 * @returns a string if it is valid
 */
declare function normalize(possibleDOI: string, opts?: Options): string | undefined;
/**
 * Builds a canonical URL pointing to https://doi.org
 *
 * @param possibleDOI
 * @returns the doi as a string
 */
declare function buildUrl(possibleDOI: string, opts?: Options): string | undefined;
declare const _default: {
    validatePart: typeof validatePart;
    validate: typeof validate;
    normalize: typeof normalize;
    buildUrl: typeof buildUrl;
};
export default _default;
